
from __future__ import print_function, unicode_literals, absolute_import, division
from reahl.doc.examples.features.validation.validation import ValidationUI

web.site_root = ValidationUI
